# coding: utf-8

"""SteelConnection Org

Currently unused and commented out - plan to re-instate this or delete it.
(YAGNI)
"""


# class Org(object):
#     """Store Org ID and name in SConAPI object as attributes."""

#     def __init__(self):
#         """Initialize the organization."""
#         self.details = {}

#     @property
#     def id(self):
#         return self.details.get('id', None)

#     @property
#     def name(self):
#         return self.details.get('name', None)

#     @property
#     def longname(self):
#         return self.details.get('longname', None)

